@@ -7,10 +7,13 @@ import (
 )
 
 func TestConnectingToAgent(t *testing.T) {
-	agents := NewConnectedAgents()
+	settings := AgentsSettings{}
+	agents := NewConnectedAgents(&settings)
+	defer agents.Shutdown()
 
 	// connect one agent and check if it is in agents map
-	agents.GetConnectedAgent("127.0.0.1:8080")
+	_, err := agents.GetConnectedAgent("127.0.0.1:8080")
+	require.NoError(t, err)
 	_, ok := agents.AgentsMap["127.0.0.1:8080"]
 	require.True(t, ok)
 }
